@@ -56,8 +56,8 @@ static char *nvstrcat(const char *str, ...);
  */
 
 int __verbosity = VERBOSITY_DEFAULT;
-
-
+int __terse = NV_FALSE;
+int __display_device_string = NV_FALSE;
 /*
  * print_version() - print version information
  */
@@ -73,7 +73,7 @@ static void print_version(void)
     nv_msg(TAB, "This program is used to configure the "
             "NVIDIA Linux graphics driver.");
     nv_msg(NULL, "");
-    nv_msg(TAB, "Copyright (C) 2004 NVIDIA Corporation.");
+    nv_msg(TAB, "Copyright (C) 2004 - 2008 NVIDIA Corporation.");
     nv_msg(NULL, "");
     
 } /* print_version() */
@@ -137,6 +137,17 @@ static const NVGetoptOption __options[] = {
 
     { "query", 'q', NVGETOPT_HAS_ARGUMENT, print_query_help, NULL },
 
+    { "terse", 't', 0, NULL,
+      "When querying attribute values with the '--query' commandline option, "
+      "only print the current value, rather than the more verbose description "
+      "of the attribute, its valid values, and its current value." },
+
+    { "display-device-string", 'd', 0, NULL,
+      "When printing attribute values in response to the '--query' option, "
+      "if the attribute value is a display device mask, print the value "
+      "as a list of display devices (e.g., \"CRT-0, DFP-0\"), rather than "
+      "a hexidecimal bitmask (e.g., 0x00010001)." },
+
     { "glxinfo", 'g', 0, NULL,
       "Print GLX Information for the X display and exit." },
     
@@ -351,6 +362,8 @@ Options *parse_command_line(int argc, char *argv[], char *dpy)
             break;
         case CONFIG_FILE_OPTION: op->config = strval; break;
         case 'g': print_glxinfo(NULL); exit(0); break;
+        case 't': __terse = NV_TRUE; break;
+        case 'd': __display_device_string = NV_TRUE; break;
         default:
             nv_error_msg("Invalid commandline, please run `%s --help` "
                          "for usage information.\n", argv[0]);
