@@ -41,24 +41,40 @@ int main(int argc, char **argv)
     CtrlHandles *h;
     NvCtrlAttributeHandle **screen_handles = NULL;
     NvCtrlAttributeHandle **gpu_handles = NULL;
-    NvCtrlAttributeHandle **vcsc_handles = NULL;
+    NvCtrlAttributeHandle **vcs_handles = NULL;
     Options *op;
-    int ret, i, num_screen_handles, num_gpu_handles, num_vcsc_handles;
-    
+    int ret, i, num_screen_handles, num_gpu_handles, num_vcs_handles;
+    char *dpy = NULL;
+    int gui = 0;
+
     /*
      * initialize the ui
      *
      * XXX it would be nice if we didn't do this up front, since we
      * may not even use the gui, but we want the toolkit to have a
-     * chance to parse the commandline before we do... we should
-     * investigate gtk_init_check().
+     * chance to parse the commandline before we do...
+     *
+     * gui flag used to decide if ctk should be used or not, as
+     * the user might just use control the display from a remote console
+     * but for some reason cannot initialize the gtk gui. - TY 2005-05-27
      */
-    
-    ctk_init(&argc, &argv);
+
+    if (ctk_init_check(&argc, &argv)) {
+        dpy = ctk_get_display();
+        gui = 1;
+    }
     
     /* parse the commandline */
     
-    op = parse_command_line(argc, argv, ctk_get_display());
+    op = parse_command_line(argc, argv, dpy);
+
+    /* quit here if we don't have a ctrl_display - TY 2005-05-27 */
+
+    if (op->ctrl_display == NULL) {
+        nv_error_msg("The control display is undefined; please run "
+                     "`%s --help` for usage information.\n", argv[0]);
+        return 1;
+    }
 
     /* process any query or assignment commandline options */
 
@@ -109,6 +125,17 @@ int main(int argc, char **argv)
         return ret ? 0 : 1;
     }
 
+    /*
+     * past this point, we need to be able to create a gui; fail if
+     * the gui isn't available; TY 2005-05-27
+     */
+
+    if (gui == 0) {
+        nv_error_msg("Unable to create nvidia-settings GUI; please run "
+                     "`%s --help` for usage information.\n", argv[0]);
+        return 1;
+    }
+
     /* allocate the CtrlHandles for this X screen */
 
     h = nv_alloc_ctrl_handles(op->ctrl_display);
@@ -150,17 +177,17 @@ int main(int argc, char **argv)
         }
     }
 
-    num_vcsc_handles = h->targets[VCSC_TARGET].n;
+    num_vcs_handles = h->targets[VCS_TARGET].n;
 
-    if (num_vcsc_handles) {
-        vcsc_handles =
-            malloc(num_vcsc_handles * sizeof(NvCtrlAttributeHandle *));
-        if (vcsc_handles) {
-            for (i = 0; i < num_vcsc_handles; i++) {
-                vcsc_handles[i] = h->targets[VCSC_TARGET].t[i].h;
+    if (num_vcs_handles) {
+        vcs_handles =
+            malloc(num_vcs_handles * sizeof(NvCtrlAttributeHandle *));
+        if (vcs_handles) {
+            for (i = 0; i < num_vcs_handles; i++) {
+                vcs_handles[i] = h->targets[VCS_TARGET].t[i].h;
             }
         } else {
-            num_vcsc_handles = 0;
+            num_vcs_handles = 0;
         }
     }
     
@@ -168,8 +195,8 @@ int main(int argc, char **argv)
 
     ctk_main(screen_handles, num_screen_handles,
              gpu_handles, num_gpu_handles,
-             vcsc_handles, num_vcsc_handles,
-             p, &conf);
+             vcs_handles, num_vcs_handles,
+             p, &conf, h);
     
     /* write the configuration file */
 
